.. _contact:

Contact
=======

Points of Contact
-----------------

`Our general email`_  is the best place to shoot any questions you may have.

.. _Our general email: info@pyladies.com

If you have more casual questions, IRC is one of the best places to start.  You can usually find several of the main PyLadies points of contact in #pyladies.

IRC #pyladies Community
-----------------------

Whether or not you’re part of a local chapter, the IRC #pyladies community welcomes you. #pyladies is on irc.freenode.net. Instructions on how to chat in #pyladies IRC are `here`_.

.. _here: http://www.pyladies.com/blog/irc-resources/

Quite a few well-known men and women in the Python community participate there and try to keep it a friendly place. Ask Python questions there, talk about what your local chapter is up to, or just say hi.

Anyone can plan and host virtual meetups in IRC #pyladies. You should host one! Just tell one of the ops to update the topic with info about your meetup. See the “Promotion” section for further details about how we can help spread word.

You can also create #pyladies-whatever IRC channels for your country, language, interest group, etc. Ask sandpy for help registering your channel under the #pyladies namespace.